faker\_file.providers.pdf\_file.generators package
==================================================

Submodules
----------

faker\_file.providers.pdf\_file.generators.pdfkit\_generator module
-------------------------------------------------------------------

.. automodule:: faker_file.providers.pdf_file.generators.pdfkit_generator
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.providers.pdf\_file.generators.reportlab\_generator module
----------------------------------------------------------------------

.. automodule:: faker_file.providers.pdf_file.generators.reportlab_generator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers.pdf_file.generators
   :members:
   :undoc-members:
   :show-inheritance:
